#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Decimal
version:              0.5.2
visibility:           public
id:                   Decimal-0.5.2-hHl7rpUc22C3t4FldYtUo
key:                  Decimal-0.5.2-hHl7rpUc22C3t4FldYtUo
license:              BSD-3-Clause
copyright:            Paul Johnson, 2013, 2018, 2021.
maintainer:           paul@cogito.org.uk
author:               Paul Johnson
stability:            beta
homepage:             https://github.com/PaulJohnson/Haskell-Decimal
synopsis:             Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.

category:             Math
abi:                  dabec65e3e06721999bfb68ca067e829
exposed:              True
exposed-modules:      Data.Decimal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/Decimal-0.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/Decimal-0.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/Decimal-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-decimal
hs-libraries:         HSDecimal-0.5.2-hHl7rpUc22C3t4FldYtUo
depends:              base-4.18.2.1 deepseq-1.4.8.1
haddock-interfaces:   /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html:         /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

